@@ -22,14 +22,25 @@ done
 shift
 if test "z$1" = "z"; then dbus_usage; fi
 
+gconf_stop ()
+{
+  local pid=$(dbus-send --print-reply --dest=org.freedesktop.DBus /org/freedesktop/DBus org.freedesktop.DBus.GetConnectionUnixProcessID string:org.gnome.GConf | tail -n 1 | awk ' { print $2; } ')
+  kill -KILL $pid
+}
+
 cleanup ()
 {
     eds_stop
+    gconf_stop
     dbus_stop
+    test -d ../data/gconf.d && rm -rf ../data/gconf.d
 }
 
 trap cleanup INT HUP TERM
 
+# In case the previous run left some junk around...
+test -d ../data/gconf.d && rm -rf ../data/gconf.d
+
 eds_init_settings
 dbus_init 0
 
